@@ -1,6 +1,7 @@
 
 /*
- * Copyright (C) 1991, 1992, 1993, 2021, 2022, 2023, 2024 by Chris Thewalt (thewalt@ce.berkeley.edu)
+ * Copyright (C) 1991, 1992, 1993, 2021, 2022, 2023, 2024, 2025 by Chris Thewalt
+ * (thewalt@ce.berkeley.edu)
  *
  * Permission to use, copy, modify, and distribute this software
  * for any purpose and without fee is hereby granted, provided
@@ -119,14 +120,14 @@ namespace {
 #endif
 
 namespace {
-#ifdef __unix__
+#if defined(__unix__) && !defined(NO_TERMIOS)
 #include <termios.h>
   struct termios io_new_termios, io_old_termios;
 #endif
 
   void gl_char_init() /* turn off input echo */
   {
-#ifdef __unix__
+#if defined(__unix__) && !defined(NO_TERMIOS)
     tcgetattr(0, &io_old_termios);
     io_new_termios = io_old_termios;
     io_new_termios.c_iflag &= ~(BRKINT | ISTRIP | IXON | IXOFF);
@@ -140,7 +141,7 @@ namespace {
 
   void gl_char_cleanup() /* undo effects of gl_char_init */
   {
-#ifdef __unix__
+#if defined(__unix__) && !defined(NO_TERMIOS)
     tcsetattr(0, TCSANOW, &io_old_termios);
 #endif /* __unix__ */
   }
@@ -197,7 +198,7 @@ namespace {
   int gl_getc()
   /* get a character without echoing it to screen */
   {
-#ifdef __unix__
+#if defined(__unix__)
     char ch;
     while (read(0, &ch, 1) == -1) {
       if (errno != EINTR) {
@@ -248,14 +249,14 @@ namespace {
   void gl_puts(const char *const buf)
   {
     if (buf) {
-      int len = strlen(buf);
+      auto len = strlen(buf);
       write(1, buf, len);
     }
   }
 
   [[noreturn]] void gl_error(const char *const buf)
   {
-    int len = strlen(buf);
+    auto len = strlen(buf);
 
     gl_cleanup();
     write(2, buf, len);
@@ -268,7 +269,7 @@ namespace {
     if (gl_init_done < 0) { /* -1 only on startup */
       const char *cp = (const char *)getenv("COLUMNS");
       if (cp != nullptr) {
-        int w = strtol(cp, nullptr, 10);
+        auto w = strtoul(cp, nullptr, 10);
         if (w > 20)
           SEAMS::gl_setwidth(w);
       }
@@ -295,7 +296,7 @@ namespace {
 } // namespace
 
 namespace SEAMS {
-  void gl_setwidth(int w)
+  void gl_setwidth(size_t w)
   {
     if (w > 250) {
       w = 250;
@@ -604,9 +605,9 @@ namespace {
       gl_width = gl_termw - strlen(prompt);
     }
     else if (strcmp(prompt, last_prompt) != 0) {
-      int l1 = strlen(last_prompt);
-      int l2 = strlen(prompt);
-      gl_cnt = gl_cnt + l1 - l2;
+      auto l1 = strlen(last_prompt);
+      auto l2 = strlen(prompt);
+      gl_cnt  = gl_cnt + l1 - l2;
       copy_string(last_prompt, prompt, 80);
       gl_putc('\r');
       gl_puts(prompt);
@@ -744,11 +745,11 @@ namespace SEAMS {
       p++;
     }
     if (*p) {
-      int len = strlen(buf);
+      auto len = strlen(buf);
       if (strchr(p, '\n')) { /* previously line already has NL stripped */
         len--;
       }
-      if ((prev == nullptr) || ((int)strlen(prev) != len) || strncmp(prev, buf, (size_t)len) != 0) {
+      if ((prev == nullptr) || (strlen(prev) != len) || strncmp(prev, buf, len) != 0) {
         hist_buf[hist_last] = hist_save(buf);
         prev                = hist_buf[hist_last];
         hist_last           = (hist_last + 1) % HIST_SIZE;
@@ -800,7 +801,7 @@ namespace {
   /* makes a copy of the string */
   {
     char       *s   = nullptr;
-    size_t      len = strlen(p);
+    auto        len = strlen(p);
     const char *nl  = strpbrk(p, "\n\r");
 
     if (nl) {
