@@ -154,7 +154,7 @@ int ex_open_int(const char *path, int mode, int *comp_ws, int *io_ws, float *ver
     }
 #endif
 
-    if ((status = nc_open(canon_path, nc_mode, &exoid)) != NC_NOERR) {
+    if ((status = nc_open(canon_path, nc_mode, &exoid)) != EX_NOERR) {
       /* NOTE: netCDF returns an id of -1 on an error - but no error code! */
       /* It is possible that the user is trying to open a netcdf4
          file, but the netcdf4 capabilities aren't available in the
@@ -190,6 +190,8 @@ int ex_open_int(const char *path, int mode, int *comp_ws, int *io_ws, float *ver
                  "issue.\n",
                  canon_path);
         ex_err(__func__, errmsg, status);
+        free(canon_path);
+        EX_FUNC_LEAVE(EX_FATAL);
 #else
         /* This is an hdf5 (netcdf4) file. If NC_HAS_HDF5 is not defined,
            then we either don't have hdf5 support in this netcdf version,
@@ -206,6 +208,8 @@ int ex_open_int(const char *path, int mode, int *comp_ws, int *io_ws, float *ver
                  "other issue.\n",
                  canon_path);
         ex_err(__func__, errmsg, status);
+        free(canon_path);
+        EX_FUNC_LEAVE(EX_FATAL);
 #endif
       }
       else if (type == 4) {
@@ -217,6 +221,8 @@ int ex_open_int(const char *path, int mode, int *comp_ws, int *io_ws, float *ver
                  "issue \n",
                  canon_path);
         ex_err(__func__, errmsg, status);
+        free(canon_path);
+        EX_FUNC_LEAVE(EX_FATAL);
 #else
         /* This is an cdf5 (64BIT_DATA) file. If NC_64BIT_DATA is not defined,
            then we either don't have cdf5 support in this netcdf version,
@@ -233,6 +239,8 @@ int ex_open_int(const char *path, int mode, int *comp_ws, int *io_ws, float *ver
                  "other issue \n",
                  canon_path);
         ex_err(__func__, errmsg, status);
+        free(canon_path);
+        EX_FUNC_LEAVE(EX_FATAL);
 
 #endif
       }
@@ -272,7 +280,7 @@ int ex_open_int(const char *path, int mode, int *comp_ws, int *io_ws, float *ver
 #endif
     }
 #endif
-    if ((status = nc_open(canon_path, nc_mode, &exoid)) != NC_NOERR) {
+    if ((status = nc_open(canon_path, nc_mode, &exoid)) != EX_NOERR) {
       /* NOTE: netCDF returns an id of -1 on an error - but no error code! */
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: failed to open %s for read/write.\n\tEither the file "
@@ -285,7 +293,7 @@ int ex_open_int(const char *path, int mode, int *comp_ws, int *io_ws, float *ver
     }
 
     /* turn off automatic filling of netCDF variables */
-    if ((status = nc_set_fill(exoid, NC_NOFILL, &old_fill)) != NC_NOERR) {
+    if ((status = nc_set_fill(exoid, NC_NOFILL, &old_fill)) != EX_NOERR) {
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to set nofill mode in file id %d named %s",
                exoid, canon_path);
       ex_err_fn(exoid, __func__, errmsg, status);
@@ -297,9 +305,9 @@ int ex_open_int(const char *path, int mode, int *comp_ws, int *io_ws, float *ver
     int    stat_att     = nc_inq_att(exoid, NC_GLOBAL, ATT_MAX_NAME_LENGTH, &att_type, &att_len);
     int    dim_str_name = 0;
     int    stat_dim     = nc_inq_dimid(exoid, DIM_STR_NAME, &dim_str_name);
-    if (stat_att != NC_NOERR || stat_dim != NC_NOERR) {
+    if (stat_att != EX_NOERR || stat_dim != EX_NOERR) {
       /* This must still be nc_redef */
-      if ((status = nc_redef(exoid)) != NC_NOERR) {
+      if ((status = nc_redef(exoid)) != EX_NOERR) {
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to place file id %d named %s into define mode", exoid, canon_path);
         ex_err_fn(exoid, __func__, errmsg, status);
@@ -307,10 +315,10 @@ int ex_open_int(const char *path, int mode, int *comp_ws, int *io_ws, float *ver
         EX_FUNC_LEAVE(EX_FATAL);
       }
 
-      if (stat_att != NC_NOERR) {
+      if (stat_att != EX_NOERR) {
         int max_so_far = 32;
         if ((status = nc_put_att_int(exoid, NC_GLOBAL, ATT_MAX_NAME_LENGTH, NC_INT, 1,
-                                     &max_so_far)) != NC_NOERR) {
+                                     &max_so_far)) != EX_NOERR) {
           snprintf(errmsg, MAX_ERR_LENGTH,
                    "ERROR: failed to add maximum_name_length attribute in file id %d", exoid);
           ex_err_fn(exoid, __func__, errmsg, status);
@@ -321,10 +329,10 @@ int ex_open_int(const char *path, int mode, int *comp_ws, int *io_ws, float *ver
 
       /* If the DIM_STR_NAME variable does not exist on the database, we need to
        * add it now. */
-      if (stat_dim != NC_NOERR) {
+      if (stat_dim != EX_NOERR) {
         /* Not found; set to default value of 32+1. */
         int max_name = exi_default_max_name_length < 32 ? 32 : exi_default_max_name_length;
-        if ((status = nc_def_dim(exoid, DIM_STR_NAME, max_name + 1, &dim_str_name)) != NC_NOERR) {
+        if ((status = nc_def_dim(exoid, DIM_STR_NAME, max_name + 1, &dim_str_name)) != EX_NOERR) {
           snprintf(errmsg, MAX_ERR_LENGTH,
                    "ERROR: failed to define string name dimension in file id %d named %s", exoid,
                    canon_path);
@@ -333,7 +341,7 @@ int ex_open_int(const char *path, int mode, int *comp_ws, int *io_ws, float *ver
           EX_FUNC_LEAVE(EX_FATAL);
         }
       }
-      if ((status = nc_enddef(exoid)) != NC_NOERR) {
+      if ((status = nc_enddef(exoid)) != EX_NOERR) {
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to exit define mode in file id %d", exoid);
         ex_err_fn(exoid, __func__, errmsg, status);
         free(canon_path);
@@ -346,7 +354,7 @@ int ex_open_int(const char *path, int mode, int *comp_ws, int *io_ws, float *ver
    * floating point and integer values stored in the file
    */
 
-  if ((status = nc_get_att_float(exoid, NC_GLOBAL, ATT_VERSION, version)) != NC_NOERR) {
+  if ((status = nc_get_att_float(exoid, NC_GLOBAL, ATT_VERSION, version)) != EX_NOERR) {
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get database version for file id: %d",
              exoid);
     ex_err_fn(exoid, __func__, errmsg, status);
@@ -363,10 +371,10 @@ int ex_open_int(const char *path, int mode, int *comp_ws, int *io_ws, float *ver
     EX_FUNC_LEAVE(EX_FATAL);
   }
 
-  if (nc_get_att_int(exoid, NC_GLOBAL, ATT_FLT_WORDSIZE, &file_wordsize) != NC_NOERR) {
+  if (nc_get_att_int(exoid, NC_GLOBAL, ATT_FLT_WORDSIZE, &file_wordsize) != EX_NOERR) {
     /* try old (prior to db version 2.02) attribute name */
     if ((status = nc_get_att_int(exoid, NC_GLOBAL, ATT_FLT_WORDSIZE_BLANK, &file_wordsize)) !=
-        NC_NOERR) {
+        EX_NOERR) {
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get file wordsize from file id: %d",
                exoid);
       ex_err_fn(exoid, __func__, errmsg, status);
@@ -380,7 +388,7 @@ int ex_open_int(const char *path, int mode, int *comp_ws, int *io_ws, float *ver
    * Older files don't have the attribute, so it is not an error if it is
    * missing
    */
-  if (nc_get_att_int(exoid, NC_GLOBAL, ATT_INT64_STATUS, &int64_status) != NC_NOERR) {
+  if (nc_get_att_int(exoid, NC_GLOBAL, ATT_INT64_STATUS, &int64_status) != EX_NOERR) {
     int64_status = 0; /* Just in case it gets munged by a failed get_att_int call */
   }
 
